git.delta.rocks / unique-network / refs/commits / 53625bbe3192

difftreelog

rename: CrossAccount -> CrossAddress

Trubnikov Sergey2022-12-22parent: #b25659a.patch.diff
in: master

30 files changed

modifiedpallets/common/src/erc.rsdiffbeforeafterboth
--- a/pallets/common/src/erc.rs
+++ b/pallets/common/src/erc.rs
@@ -244,7 +244,7 @@
 	fn set_collection_sponsor_cross(
 		&mut self,
 		caller: caller,
-		sponsor: eth::CrossAccount,
+		sponsor: eth::CrossAddress,
 	) -> Result<void> {
 		self.consume_store_reads_and_writes(1, 1)?;
 
@@ -284,13 +284,13 @@
 	/// Get current sponsor.
 	///
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
-	fn collection_sponsor(&self) -> Result<eth::CrossAccount> {
+	fn collection_sponsor(&self) -> Result<eth::CrossAddress> {
 		let sponsor = match self.collection.sponsorship.sponsor() {
 			Some(sponsor) => sponsor,
 			None => return Ok(Default::default()),
 		};
 
-		Ok(eth::CrossAccount::from_sub::<T>(&sponsor))
+		Ok(eth::CrossAddress::from_sub::<T>(&sponsor))
 	}
 
 	/// Get current collection limits.
@@ -376,7 +376,7 @@
 	fn add_collection_admin_cross(
 		&mut self,
 		caller: caller,
-		new_admin: eth::CrossAccount,
+		new_admin: eth::CrossAddress,
 	) -> Result<void> {
 		self.consume_store_reads_and_writes(2, 2)?;
 
@@ -391,7 +391,7 @@
 	fn remove_collection_admin_cross(
 		&mut self,
 		caller: caller,
-		admin: eth::CrossAccount,
+		admin: eth::CrossAddress,
 	) -> Result<void> {
 		self.consume_store_reads_and_writes(2, 2)?;
 
@@ -539,7 +539,7 @@
 	/// Checks that user allowed to operate with collection.
 	///
 	/// @param user User address to check.
-	fn allowlisted_cross(&self, user: eth::CrossAccount) -> Result<bool> {
+	fn allowlisted_cross(&self, user: eth::CrossAddress) -> Result<bool> {
 		let user = user.into_sub_cross_account::<T>()?;
 		Ok(Pallet::<T>::allowed(self.id, user))
 	}
@@ -563,7 +563,7 @@
 	fn add_to_collection_allow_list_cross(
 		&mut self,
 		caller: caller,
-		user: eth::CrossAccount,
+		user: eth::CrossAddress,
 	) -> Result<void> {
 		self.consume_store_writes(1)?;
 
@@ -592,7 +592,7 @@
 	fn remove_from_collection_allow_list_cross(
 		&mut self,
 		caller: caller,
-		user: eth::CrossAccount,
+		user: eth::CrossAddress,
 	) -> Result<void> {
 		self.consume_store_writes(1)?;
 
@@ -630,7 +630,7 @@
 	///
 	/// @param user User cross account to verify
 	/// @return "true" if account is the owner or admin
-	fn is_owner_or_admin_cross(&self, user: eth::CrossAccount) -> Result<bool> {
+	fn is_owner_or_admin_cross(&self, user: eth::CrossAddress) -> Result<bool> {
 		let user = user.into_sub_cross_account::<T>()?;
 		Ok(self.is_owner_or_admin(&user))
 	}
@@ -651,8 +651,8 @@
 	///
 	/// @return Tuble with sponsor address and his substrate mirror.
 	/// If address is canonical then substrate mirror is zero and vice versa.
-	fn collection_owner(&self) -> Result<eth::CrossAccount> {
-		Ok(eth::CrossAccount::from_sub_cross_account::<T>(
+	fn collection_owner(&self) -> Result<eth::CrossAddress> {
+		Ok(eth::CrossAddress::from_sub_cross_account::<T>(
 			&T::CrossAccountId::from_sub(self.owner.clone()),
 		))
 	}
@@ -675,9 +675,9 @@
 	///
 	/// @return Vector of tuples with admins address and his substrate mirror.
 	/// If address is canonical then substrate mirror is zero and vice versa.
-	fn collection_admins(&self) -> Result<Vec<eth::CrossAccount>> {
+	fn collection_admins(&self) -> Result<Vec<eth::CrossAddress>> {
 		let result = crate::IsAdmin::<T>::iter_prefix((self.id,))
-			.map(|(admin, _)| eth::CrossAccount::from_sub_cross_account::<T>(&admin))
+			.map(|(admin, _)| eth::CrossAddress::from_sub_cross_account::<T>(&admin))
 			.collect();
 		Ok(result)
 	}
@@ -689,7 +689,7 @@
 	fn change_collection_owner_cross(
 		&mut self,
 		caller: caller,
-		new_owner: eth::CrossAccount,
+		new_owner: eth::CrossAddress,
 	) -> Result<void> {
 		self.consume_store_writes(1)?;
 
modifiedpallets/common/src/eth.rsdiffbeforeafterboth
--- a/pallets/evm-contract-helpers/src/eth.rs
+++ b/pallets/evm-contract-helpers/src/eth.rs
@@ -174,9 +174,9 @@
 	///
 	/// @param contractAddress The contract for which a sponsor is requested.
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
-	fn sponsor(&self, contract_address: address) -> Result<pallet_common::eth::CrossAccount> {
+	fn sponsor(&self, contract_address: address) -> Result<pallet_common::eth::CrossAddress> {
 		Ok(
-			pallet_common::eth::CrossAccount::from_sub_cross_account::<T>(
+			pallet_common::eth::CrossAddress::from_sub_cross_account::<T>(
 				&Pallet::<T>::get_sponsor(contract_address).ok_or("Contract has no sponsor")?,
 			),
 		)
modifiedpallets/evm-contract-helpers/src/stubs/ContractHelpers.rawdiffbeforeafterboth

binary blob — no preview

modifiedpallets/evm-contract-helpers/src/stubs/ContractHelpers.soldiffbeforeafterboth
--- a/pallets/evm-contract-helpers/src/stubs/ContractHelpers.sol
+++ b/pallets/evm-contract-helpers/src/stubs/ContractHelpers.sol
@@ -96,11 +96,11 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x766c4f37,
 	///  or in textual repr: sponsor(address)
-	function sponsor(address contractAddress) public view returns (CrossAccount memory) {
+	function sponsor(address contractAddress) public view returns (CrossAddress memory) {
 		require(false, stub_error);
 		contractAddress;
 		dummy;
-		return CrossAccount(0x0000000000000000000000000000000000000000, 0);
+		return CrossAddress(0x0000000000000000000000000000000000000000, 0);
 	}
 
 	/// Check tat contract has confirmed sponsor.
@@ -266,7 +266,7 @@
 }
 
 /// @dev Cross account struct
-struct CrossAccount {
+struct CrossAddress {
 	address eth;
 	uint256 sub;
 }
modifiedpallets/fungible/src/erc.rsdiffbeforeafterboth
--- a/pallets/fungible/src/erc.rs
+++ b/pallets/fungible/src/erc.rs
@@ -177,7 +177,7 @@
 	fn mint_cross(
 		&mut self,
 		caller: caller,
-		to: pallet_common::eth::CrossAccount,
+		to: pallet_common::eth::CrossAddress,
 		amount: uint256,
 	) -> Result<bool> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -195,7 +195,7 @@
 	fn approve_cross(
 		&mut self,
 		caller: caller,
-		spender: pallet_common::eth::CrossAccount,
+		spender: pallet_common::eth::CrossAddress,
 		amount: uint256,
 	) -> Result<bool> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -236,7 +236,7 @@
 	fn burn_from_cross(
 		&mut self,
 		caller: caller,
-		from: pallet_common::eth::CrossAccount,
+		from: pallet_common::eth::CrossAddress,
 		amount: uint256,
 	) -> Result<bool> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -278,7 +278,7 @@
 	fn transfer_cross(
 		&mut self,
 		caller: caller,
-		to: pallet_common::eth::CrossAccount,
+		to: pallet_common::eth::CrossAddress,
 		amount: uint256,
 	) -> Result<bool> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -296,8 +296,8 @@
 	fn transfer_from_cross(
 		&mut self,
 		caller: caller,
-		from: pallet_common::eth::CrossAccount,
-		to: pallet_common::eth::CrossAccount,
+		from: pallet_common::eth::CrossAddress,
+		to: pallet_common::eth::CrossAddress,
 		amount: uint256,
 	) -> Result<bool> {
 		let caller = T::CrossAccountId::from_eth(caller);
modifiedpallets/fungible/src/stubs/UniqueFungible.rawdiffbeforeafterboth

binary blob — no preview

modifiedpallets/fungible/src/stubs/UniqueFungible.soldiffbeforeafterboth
--- a/pallets/fungible/src/stubs/UniqueFungible.sol
+++ b/pallets/fungible/src/stubs/UniqueFungible.sol
@@ -114,7 +114,7 @@
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
 	/// @dev EVM selector for this function is: 0x84a1d5a8,
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
-	function setCollectionSponsorCross(CrossAccount memory sponsor) public {
+	function setCollectionSponsorCross(CrossAddress memory sponsor) public {
 		require(false, stub_error);
 		sponsor;
 		dummy = 0;
@@ -152,10 +152,10 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
-	function collectionSponsor() public view returns (CrossAccount memory) {
+	function collectionSponsor() public view returns (CrossAddress memory) {
 		require(false, stub_error);
 		dummy;
-		return CrossAccount(0x0000000000000000000000000000000000000000, 0);
+		return CrossAddress(0x0000000000000000000000000000000000000000, 0);
 	}
 
 	/// Get current collection limits.
@@ -193,7 +193,7 @@
 	/// @param newAdmin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x859aa7d6,
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
-	function addCollectionAdminCross(CrossAccount memory newAdmin) public {
+	function addCollectionAdminCross(CrossAddress memory newAdmin) public {
 		require(false, stub_error);
 		newAdmin;
 		dummy = 0;
@@ -203,7 +203,7 @@
 	/// @param admin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x6c0cd173,
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
-	function removeCollectionAdminCross(CrossAccount memory admin) public {
+	function removeCollectionAdminCross(CrossAddress memory admin) public {
 		require(false, stub_error);
 		admin;
 		dummy = 0;
@@ -289,7 +289,7 @@
 	/// @param user User address to check.
 	/// @dev EVM selector for this function is: 0x91b6df49,
 	///  or in textual repr: allowlistedCross((address,uint256))
-	function allowlistedCross(CrossAccount memory user) public view returns (bool) {
+	function allowlistedCross(CrossAddress memory user) public view returns (bool) {
 		require(false, stub_error);
 		user;
 		dummy;
@@ -312,7 +312,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0xa0184a3a,
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
-	function addToCollectionAllowListCross(CrossAccount memory user) public {
+	function addToCollectionAllowListCross(CrossAddress memory user) public {
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -334,7 +334,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0x09ba452a,
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
-	function removeFromCollectionAllowListCross(CrossAccount memory user) public {
+	function removeFromCollectionAllowListCross(CrossAddress memory user) public {
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -370,7 +370,7 @@
 	/// @return "true" if account is the owner or admin
 	/// @dev EVM selector for this function is: 0x3e75a905,
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
-	function isOwnerOrAdminCross(CrossAccount memory user) public view returns (bool) {
+	function isOwnerOrAdminCross(CrossAddress memory user) public view returns (bool) {
 		require(false, stub_error);
 		user;
 		dummy;
@@ -394,10 +394,10 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
-	function collectionOwner() public view returns (CrossAccount memory) {
+	function collectionOwner() public view returns (CrossAddress memory) {
 		require(false, stub_error);
 		dummy;
-		return CrossAccount(0x0000000000000000000000000000000000000000, 0);
+		return CrossAddress(0x0000000000000000000000000000000000000000, 0);
 	}
 
 	// /// Changes collection owner to another account
@@ -418,10 +418,10 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
-	function collectionAdmins() public view returns (CrossAccount[] memory) {
+	function collectionAdmins() public view returns (CrossAddress[] memory) {
 		require(false, stub_error);
 		dummy;
-		return new CrossAccount[](0);
+		return new CrossAddress[](0);
 	}
 
 	/// Changes collection owner to another account
@@ -430,7 +430,7 @@
 	/// @param newOwner new owner cross account
 	/// @dev EVM selector for this function is: 0x6496c497,
 	///  or in textual repr: changeCollectionOwnerCross((address,uint256))
-	function changeCollectionOwnerCross(CrossAccount memory newOwner) public {
+	function changeCollectionOwnerCross(CrossAddress memory newOwner) public {
 		require(false, stub_error);
 		newOwner;
 		dummy = 0;
@@ -438,7 +438,7 @@
 }
 
 /// @dev Cross account struct
-struct CrossAccount {
+struct CrossAddress {
 	address eth;
 	uint256 sub;
 }
@@ -516,7 +516,7 @@
 
 	/// @dev EVM selector for this function is: 0x269e6158,
 	///  or in textual repr: mintCross((address,uint256),uint256)
-	function mintCross(CrossAccount memory to, uint256 amount) public returns (bool) {
+	function mintCross(CrossAddress memory to, uint256 amount) public returns (bool) {
 		require(false, stub_error);
 		to;
 		amount;
@@ -526,7 +526,7 @@
 
 	/// @dev EVM selector for this function is: 0x0ecd0ab0,
 	///  or in textual repr: approveCross((address,uint256),uint256)
-	function approveCross(CrossAccount memory spender, uint256 amount) public returns (bool) {
+	function approveCross(CrossAddress memory spender, uint256 amount) public returns (bool) {
 		require(false, stub_error);
 		spender;
 		amount;
@@ -556,7 +556,7 @@
 	/// @param amount The amount that will be burnt.
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
-	function burnFromCross(CrossAccount memory from, uint256 amount) public returns (bool) {
+	function burnFromCross(CrossAddress memory from, uint256 amount) public returns (bool) {
 		require(false, stub_error);
 		from;
 		amount;
@@ -577,7 +577,7 @@
 
 	/// @dev EVM selector for this function is: 0x2ada85ff,
 	///  or in textual repr: transferCross((address,uint256),uint256)
-	function transferCross(CrossAccount memory to, uint256 amount) public returns (bool) {
+	function transferCross(CrossAddress memory to, uint256 amount) public returns (bool) {
 		require(false, stub_error);
 		to;
 		amount;
@@ -588,8 +588,8 @@
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
-		CrossAccount memory from,
-		CrossAccount memory to,
+		CrossAddress memory from,
+		CrossAddress memory to,
 		uint256 amount
 	) public returns (bool) {
 		require(false, stub_error);
modifiedpallets/nonfungible/src/erc.rsdiffbeforeafterboth
--- a/pallets/nonfungible/src/erc.rs
+++ b/pallets/nonfungible/src/erc.rs
@@ -762,9 +762,9 @@
 	/// Returns the owner (in cross format) of the token.
 	///
 	/// @param tokenId Id for the token.
-	fn cross_owner_of(&self, token_id: uint256) -> Result<pallet_common::eth::CrossAccount> {
+	fn cross_owner_of(&self, token_id: uint256) -> Result<pallet_common::eth::CrossAddress> {
 		Self::token_owner(&self, token_id.try_into()?)
-			.map(|o| pallet_common::eth::CrossAccount::from_sub_cross_account::<T>(&o))
+			.map(|o| pallet_common::eth::CrossAddress::from_sub_cross_account::<T>(&o))
 			.ok_or(Error::Revert("key too large".into()))
 	}
 
@@ -812,7 +812,7 @@
 	fn approve_cross(
 		&mut self,
 		caller: caller,
-		approved: pallet_common::eth::CrossAccount,
+		approved: pallet_common::eth::CrossAddress,
 		token_id: uint256,
 	) -> Result<void> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -851,7 +851,7 @@
 	fn transfer_cross(
 		&mut self,
 		caller: caller,
-		to: pallet_common::eth::CrossAccount,
+		to: pallet_common::eth::CrossAddress,
 		token_id: uint256,
 	) -> Result<void> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -875,8 +875,8 @@
 	fn transfer_from_cross(
 		&mut self,
 		caller: caller,
-		from: pallet_common::eth::CrossAccount,
-		to: pallet_common::eth::CrossAccount,
+		from: pallet_common::eth::CrossAddress,
+		to: pallet_common::eth::CrossAddress,
 		token_id: uint256,
 	) -> Result<void> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -922,7 +922,7 @@
 	fn burn_from_cross(
 		&mut self,
 		caller: caller,
-		from: pallet_common::eth::CrossAccount,
+		from: pallet_common::eth::CrossAddress,
 		token_id: uint256,
 	) -> Result<void> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -1044,7 +1044,7 @@
 	fn mint_cross(
 		&mut self,
 		caller: caller,
-		to: pallet_common::eth::CrossAccount,
+		to: pallet_common::eth::CrossAddress,
 		properties: Vec<pallet_common::eth::Property>,
 	) -> Result<uint256> {
 		let token_id = <TokensMinted<T>>::get(self.id)
modifiedpallets/nonfungible/src/stubs/UniqueNFT.rawdiffbeforeafterboth

binary blob — no preview

modifiedpallets/nonfungible/src/stubs/UniqueNFT.soldiffbeforeafterboth
--- a/pallets/nonfungible/src/stubs/UniqueNFT.sol
+++ b/pallets/nonfungible/src/stubs/UniqueNFT.sol
@@ -256,7 +256,7 @@
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
 	/// @dev EVM selector for this function is: 0x84a1d5a8,
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
-	function setCollectionSponsorCross(CrossAccount memory sponsor) public {
+	function setCollectionSponsorCross(CrossAddress memory sponsor) public {
 		require(false, stub_error);
 		sponsor;
 		dummy = 0;
@@ -294,10 +294,10 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
-	function collectionSponsor() public view returns (CrossAccount memory) {
+	function collectionSponsor() public view returns (CrossAddress memory) {
 		require(false, stub_error);
 		dummy;
-		return CrossAccount(0x0000000000000000000000000000000000000000, 0);
+		return CrossAddress(0x0000000000000000000000000000000000000000, 0);
 	}
 
 	/// Get current collection limits.
@@ -335,7 +335,7 @@
 	/// @param newAdmin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x859aa7d6,
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
-	function addCollectionAdminCross(CrossAccount memory newAdmin) public {
+	function addCollectionAdminCross(CrossAddress memory newAdmin) public {
 		require(false, stub_error);
 		newAdmin;
 		dummy = 0;
@@ -345,7 +345,7 @@
 	/// @param admin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x6c0cd173,
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
-	function removeCollectionAdminCross(CrossAccount memory admin) public {
+	function removeCollectionAdminCross(CrossAddress memory admin) public {
 		require(false, stub_error);
 		admin;
 		dummy = 0;
@@ -431,7 +431,7 @@
 	/// @param user User address to check.
 	/// @dev EVM selector for this function is: 0x91b6df49,
 	///  or in textual repr: allowlistedCross((address,uint256))
-	function allowlistedCross(CrossAccount memory user) public view returns (bool) {
+	function allowlistedCross(CrossAddress memory user) public view returns (bool) {
 		require(false, stub_error);
 		user;
 		dummy;
@@ -454,7 +454,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0xa0184a3a,
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
-	function addToCollectionAllowListCross(CrossAccount memory user) public {
+	function addToCollectionAllowListCross(CrossAddress memory user) public {
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -476,7 +476,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0x09ba452a,
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
-	function removeFromCollectionAllowListCross(CrossAccount memory user) public {
+	function removeFromCollectionAllowListCross(CrossAddress memory user) public {
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -512,7 +512,7 @@
 	/// @return "true" if account is the owner or admin
 	/// @dev EVM selector for this function is: 0x3e75a905,
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
-	function isOwnerOrAdminCross(CrossAccount memory user) public view returns (bool) {
+	function isOwnerOrAdminCross(CrossAddress memory user) public view returns (bool) {
 		require(false, stub_error);
 		user;
 		dummy;
@@ -536,10 +536,10 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
-	function collectionOwner() public view returns (CrossAccount memory) {
+	function collectionOwner() public view returns (CrossAddress memory) {
 		require(false, stub_error);
 		dummy;
-		return CrossAccount(0x0000000000000000000000000000000000000000, 0);
+		return CrossAddress(0x0000000000000000000000000000000000000000, 0);
 	}
 
 	// /// Changes collection owner to another account
@@ -560,10 +560,10 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
-	function collectionAdmins() public view returns (CrossAccount[] memory) {
+	function collectionAdmins() public view returns (CrossAddress[] memory) {
 		require(false, stub_error);
 		dummy;
-		return new CrossAccount[](0);
+		return new CrossAddress[](0);
 	}
 
 	/// Changes collection owner to another account
@@ -572,7 +572,7 @@
 	/// @param newOwner new owner cross account
 	/// @dev EVM selector for this function is: 0x6496c497,
 	///  or in textual repr: changeCollectionOwnerCross((address,uint256))
-	function changeCollectionOwnerCross(CrossAccount memory newOwner) public {
+	function changeCollectionOwnerCross(CrossAddress memory newOwner) public {
 		require(false, stub_error);
 		newOwner;
 		dummy = 0;
@@ -580,7 +580,7 @@
 }
 
 /// @dev Cross account struct
-struct CrossAccount {
+struct CrossAddress {
 	address eth;
 	uint256 sub;
 }
@@ -817,11 +817,11 @@
 	/// @param tokenId Id for the token.
 	/// @dev EVM selector for this function is: 0x2b29dace,
 	///  or in textual repr: crossOwnerOf(uint256)
-	function crossOwnerOf(uint256 tokenId) public view returns (CrossAccount memory) {
+	function crossOwnerOf(uint256 tokenId) public view returns (CrossAddress memory) {
 		require(false, stub_error);
 		tokenId;
 		dummy;
-		return CrossAccount(0x0000000000000000000000000000000000000000, 0);
+		return CrossAddress(0x0000000000000000000000000000000000000000, 0);
 	}
 
 	/// Returns the token properties.
@@ -847,7 +847,7 @@
 	/// @param tokenId The NFT to approve
 	/// @dev EVM selector for this function is: 0x0ecd0ab0,
 	///  or in textual repr: approveCross((address,uint256),uint256)
-	function approveCross(CrossAccount memory approved, uint256 tokenId) public {
+	function approveCross(CrossAddress memory approved, uint256 tokenId) public {
 		require(false, stub_error);
 		approved;
 		tokenId;
@@ -875,7 +875,7 @@
 	/// @param tokenId The NFT to transfer
 	/// @dev EVM selector for this function is: 0x2ada85ff,
 	///  or in textual repr: transferCross((address,uint256),uint256)
-	function transferCross(CrossAccount memory to, uint256 tokenId) public {
+	function transferCross(CrossAddress memory to, uint256 tokenId) public {
 		require(false, stub_error);
 		to;
 		tokenId;
@@ -891,8 +891,8 @@
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
-		CrossAccount memory from,
-		CrossAccount memory to,
+		CrossAddress memory from,
+		CrossAddress memory to,
 		uint256 tokenId
 	) public {
 		require(false, stub_error);
@@ -925,7 +925,7 @@
 	/// @param tokenId The NFT to transfer
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
-	function burnFromCross(CrossAccount memory from, uint256 tokenId) public {
+	function burnFromCross(CrossAddress memory from, uint256 tokenId) public {
 		require(false, stub_error);
 		from;
 		tokenId;
@@ -977,7 +977,7 @@
 	/// @return uint256 The id of the newly minted token
 	/// @dev EVM selector for this function is: 0xb904db03,
 	///  or in textual repr: mintCross((address,uint256),(string,bytes)[])
-	function mintCross(CrossAccount memory to, Property[] memory properties) public returns (uint256) {
+	function mintCross(CrossAddress memory to, Property[] memory properties) public returns (uint256) {
 		require(false, stub_error);
 		to;
 		properties;
modifiedpallets/refungible/src/erc.rsdiffbeforeafterboth
--- a/pallets/refungible/src/erc.rs
+++ b/pallets/refungible/src/erc.rs
@@ -797,9 +797,9 @@
 	/// Returns the owner (in cross format) of the token.
 	///
 	/// @param tokenId Id for the token.
-	fn cross_owner_of(&self, token_id: uint256) -> Result<pallet_common::eth::CrossAccount> {
+	fn cross_owner_of(&self, token_id: uint256) -> Result<pallet_common::eth::CrossAddress> {
 		Self::token_owner(&self, token_id.try_into()?)
-			.map(|o| pallet_common::eth::CrossAccount::from_sub_cross_account::<T>(&o))
+			.map(|o| pallet_common::eth::CrossAddress::from_sub_cross_account::<T>(&o))
 			.ok_or(Error::Revert("key too large".into()))
 	}
 
@@ -869,7 +869,7 @@
 	fn transfer_cross(
 		&mut self,
 		caller: caller,
-		to: pallet_common::eth::CrossAccount,
+		to: pallet_common::eth::CrossAddress,
 		token_id: uint256,
 	) -> Result<void> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -897,8 +897,8 @@
 	fn transfer_from_cross(
 		&mut self,
 		caller: caller,
-		from: pallet_common::eth::CrossAccount,
-		to: pallet_common::eth::CrossAccount,
+		from: pallet_common::eth::CrossAddress,
+		to: pallet_common::eth::CrossAddress,
 		token_id: uint256,
 	) -> Result<void> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -953,7 +953,7 @@
 	fn burn_from_cross(
 		&mut self,
 		caller: caller,
-		from: pallet_common::eth::CrossAccount,
+		from: pallet_common::eth::CrossAddress,
 		token_id: uint256,
 	) -> Result<void> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -1090,7 +1090,7 @@
 	fn mint_cross(
 		&mut self,
 		caller: caller,
-		to: pallet_common::eth::CrossAccount,
+		to: pallet_common::eth::CrossAddress,
 		properties: Vec<pallet_common::eth::Property>,
 	) -> Result<uint256> {
 		let token_id = <TokensMinted<T>>::get(self.id)
modifiedpallets/refungible/src/erc_token.rsdiffbeforeafterboth
--- a/pallets/refungible/src/erc_token.rs
+++ b/pallets/refungible/src/erc_token.rs
@@ -224,7 +224,7 @@
 	fn burn_from_cross(
 		&mut self,
 		caller: caller,
-		from: pallet_common::eth::CrossAccount,
+		from: pallet_common::eth::CrossAddress,
 		amount: uint256,
 	) -> Result<bool> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -250,7 +250,7 @@
 	fn approve_cross(
 		&mut self,
 		caller: caller,
-		spender: pallet_common::eth::CrossAccount,
+		spender: pallet_common::eth::CrossAddress,
 		amount: uint256,
 	) -> Result<bool> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -280,7 +280,7 @@
 	fn transfer_cross(
 		&mut self,
 		caller: caller,
-		to: pallet_common::eth::CrossAccount,
+		to: pallet_common::eth::CrossAddress,
 		amount: uint256,
 	) -> Result<bool> {
 		let caller = T::CrossAccountId::from_eth(caller);
@@ -303,8 +303,8 @@
 	fn transfer_from_cross(
 		&mut self,
 		caller: caller,
-		from: pallet_common::eth::CrossAccount,
-		to: pallet_common::eth::CrossAccount,
+		from: pallet_common::eth::CrossAddress,
+		to: pallet_common::eth::CrossAddress,
 		amount: uint256,
 	) -> Result<bool> {
 		let caller = T::CrossAccountId::from_eth(caller);
modifiedpallets/refungible/src/stubs/UniqueRefungible.rawdiffbeforeafterboth
before · pallets/refungible/src/stubs/UniqueRefungible.raw

binary blob (application/octet-stream) — download

after · pallets/refungible/src/stubs/UniqueRefungible.raw

binary blob (application/octet-stream) — download

modifiedpallets/refungible/src/stubs/UniqueRefungible.soldiffbeforeafterboth
--- a/pallets/refungible/src/stubs/UniqueRefungible.sol
+++ b/pallets/refungible/src/stubs/UniqueRefungible.sol
@@ -256,7 +256,7 @@
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
 	/// @dev EVM selector for this function is: 0x84a1d5a8,
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
-	function setCollectionSponsorCross(CrossAccount memory sponsor) public {
+	function setCollectionSponsorCross(CrossAddress memory sponsor) public {
 		require(false, stub_error);
 		sponsor;
 		dummy = 0;
@@ -294,10 +294,10 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
-	function collectionSponsor() public view returns (CrossAccount memory) {
+	function collectionSponsor() public view returns (CrossAddress memory) {
 		require(false, stub_error);
 		dummy;
-		return CrossAccount(0x0000000000000000000000000000000000000000, 0);
+		return CrossAddress(0x0000000000000000000000000000000000000000, 0);
 	}
 
 	/// Get current collection limits.
@@ -335,7 +335,7 @@
 	/// @param newAdmin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x859aa7d6,
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
-	function addCollectionAdminCross(CrossAccount memory newAdmin) public {
+	function addCollectionAdminCross(CrossAddress memory newAdmin) public {
 		require(false, stub_error);
 		newAdmin;
 		dummy = 0;
@@ -345,7 +345,7 @@
 	/// @param admin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x6c0cd173,
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
-	function removeCollectionAdminCross(CrossAccount memory admin) public {
+	function removeCollectionAdminCross(CrossAddress memory admin) public {
 		require(false, stub_error);
 		admin;
 		dummy = 0;
@@ -431,7 +431,7 @@
 	/// @param user User address to check.
 	/// @dev EVM selector for this function is: 0x91b6df49,
 	///  or in textual repr: allowlistedCross((address,uint256))
-	function allowlistedCross(CrossAccount memory user) public view returns (bool) {
+	function allowlistedCross(CrossAddress memory user) public view returns (bool) {
 		require(false, stub_error);
 		user;
 		dummy;
@@ -454,7 +454,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0xa0184a3a,
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
-	function addToCollectionAllowListCross(CrossAccount memory user) public {
+	function addToCollectionAllowListCross(CrossAddress memory user) public {
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -476,7 +476,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0x09ba452a,
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
-	function removeFromCollectionAllowListCross(CrossAccount memory user) public {
+	function removeFromCollectionAllowListCross(CrossAddress memory user) public {
 		require(false, stub_error);
 		user;
 		dummy = 0;
@@ -512,7 +512,7 @@
 	/// @return "true" if account is the owner or admin
 	/// @dev EVM selector for this function is: 0x3e75a905,
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
-	function isOwnerOrAdminCross(CrossAccount memory user) public view returns (bool) {
+	function isOwnerOrAdminCross(CrossAddress memory user) public view returns (bool) {
 		require(false, stub_error);
 		user;
 		dummy;
@@ -536,10 +536,10 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
-	function collectionOwner() public view returns (CrossAccount memory) {
+	function collectionOwner() public view returns (CrossAddress memory) {
 		require(false, stub_error);
 		dummy;
-		return CrossAccount(0x0000000000000000000000000000000000000000, 0);
+		return CrossAddress(0x0000000000000000000000000000000000000000, 0);
 	}
 
 	// /// Changes collection owner to another account
@@ -560,10 +560,10 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
-	function collectionAdmins() public view returns (CrossAccount[] memory) {
+	function collectionAdmins() public view returns (CrossAddress[] memory) {
 		require(false, stub_error);
 		dummy;
-		return new CrossAccount[](0);
+		return new CrossAddress[](0);
 	}
 
 	/// Changes collection owner to another account
@@ -572,7 +572,7 @@
 	/// @param newOwner new owner cross account
 	/// @dev EVM selector for this function is: 0x6496c497,
 	///  or in textual repr: changeCollectionOwnerCross((address,uint256))
-	function changeCollectionOwnerCross(CrossAccount memory newOwner) public {
+	function changeCollectionOwnerCross(CrossAddress memory newOwner) public {
 		require(false, stub_error);
 		newOwner;
 		dummy = 0;
@@ -580,7 +580,7 @@
 }
 
 /// @dev Cross account struct
-struct CrossAccount {
+struct CrossAddress {
 	address eth;
 	uint256 sub;
 }
@@ -815,11 +815,11 @@
 	/// @param tokenId Id for the token.
 	/// @dev EVM selector for this function is: 0x2b29dace,
 	///  or in textual repr: crossOwnerOf(uint256)
-	function crossOwnerOf(uint256 tokenId) public view returns (CrossAccount memory) {
+	function crossOwnerOf(uint256 tokenId) public view returns (CrossAddress memory) {
 		require(false, stub_error);
 		tokenId;
 		dummy;
-		return CrossAccount(0x0000000000000000000000000000000000000000, 0);
+		return CrossAddress(0x0000000000000000000000000000000000000000, 0);
 	}
 
 	/// Returns the token properties.
@@ -860,7 +860,7 @@
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0x2ada85ff,
 	///  or in textual repr: transferCross((address,uint256),uint256)
-	function transferCross(CrossAccount memory to, uint256 tokenId) public {
+	function transferCross(CrossAddress memory to, uint256 tokenId) public {
 		require(false, stub_error);
 		to;
 		tokenId;
@@ -876,8 +876,8 @@
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
-		CrossAccount memory from,
-		CrossAccount memory to,
+		CrossAddress memory from,
+		CrossAddress memory to,
 		uint256 tokenId
 	) public {
 		require(false, stub_error);
@@ -912,7 +912,7 @@
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
-	function burnFromCross(CrossAccount memory from, uint256 tokenId) public {
+	function burnFromCross(CrossAddress memory from, uint256 tokenId) public {
 		require(false, stub_error);
 		from;
 		tokenId;
@@ -964,7 +964,7 @@
 	/// @return uint256 The id of the newly minted token
 	/// @dev EVM selector for this function is: 0xb904db03,
 	///  or in textual repr: mintCross((address,uint256),(string,bytes)[])
-	function mintCross(CrossAccount memory to, Property[] memory properties) public returns (uint256) {
+	function mintCross(CrossAddress memory to, Property[] memory properties) public returns (uint256) {
 		require(false, stub_error);
 		to;
 		properties;
modifiedpallets/refungible/src/stubs/UniqueRefungibleToken.rawdiffbeforeafterboth

binary blob — no preview

modifiedpallets/refungible/src/stubs/UniqueRefungibleToken.soldiffbeforeafterboth
--- a/pallets/refungible/src/stubs/UniqueRefungibleToken.sol
+++ b/pallets/refungible/src/stubs/UniqueRefungibleToken.sol
@@ -58,7 +58,7 @@
 	/// @param amount The amount that will be burnt.
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
-	function burnFromCross(CrossAccount memory from, uint256 amount) public returns (bool) {
+	function burnFromCross(CrossAddress memory from, uint256 amount) public returns (bool) {
 		require(false, stub_error);
 		from;
 		amount;
@@ -75,7 +75,7 @@
 	/// @param amount The amount of tokens to be spent.
 	/// @dev EVM selector for this function is: 0x0ecd0ab0,
 	///  or in textual repr: approveCross((address,uint256),uint256)
-	function approveCross(CrossAccount memory spender, uint256 amount) public returns (bool) {
+	function approveCross(CrossAddress memory spender, uint256 amount) public returns (bool) {
 		require(false, stub_error);
 		spender;
 		amount;
@@ -100,7 +100,7 @@
 	/// @param amount The amount to be transferred.
 	/// @dev EVM selector for this function is: 0x2ada85ff,
 	///  or in textual repr: transferCross((address,uint256),uint256)
-	function transferCross(CrossAccount memory to, uint256 amount) public returns (bool) {
+	function transferCross(CrossAddress memory to, uint256 amount) public returns (bool) {
 		require(false, stub_error);
 		to;
 		amount;
@@ -115,8 +115,8 @@
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
-		CrossAccount memory from,
-		CrossAccount memory to,
+		CrossAddress memory from,
+		CrossAddress memory to,
 		uint256 amount
 	) public returns (bool) {
 		require(false, stub_error);
@@ -129,7 +129,7 @@
 }
 
 /// @dev Cross account struct
-struct CrossAccount {
+struct CrossAddress {
 	address eth;
 	uint256 sub;
 }
modifiedtests/src/eth/abi/contractHelpers.jsondiffbeforeafterboth
--- a/tests/src/eth/abi/contractHelpers.json
+++ b/tests/src/eth/abi/contractHelpers.json
@@ -226,7 +226,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "",
         "type": "tuple"
       }
modifiedtests/src/eth/abi/fungible.jsondiffbeforeafterboth
--- a/tests/src/eth/abi/fungible.json
+++ b/tests/src/eth/abi/fungible.json
@@ -56,7 +56,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "newAdmin",
         "type": "tuple"
       }
@@ -73,7 +73,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -100,7 +100,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -127,7 +127,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "spender",
         "type": "tuple"
       },
@@ -154,7 +154,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "from",
         "type": "tuple"
       },
@@ -172,7 +172,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "newOwner",
         "type": "tuple"
       }
@@ -191,7 +191,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount[]",
+        "internalType": "struct CrossAddress[]",
         "name": "",
         "type": "tuple[]"
       }
@@ -282,7 +282,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "",
         "type": "tuple"
       }
@@ -325,7 +325,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "",
         "type": "tuple"
       }
@@ -384,7 +384,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -428,7 +428,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
@@ -453,7 +453,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "admin",
         "type": "tuple"
       }
@@ -477,7 +477,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -575,7 +575,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "sponsor",
         "type": "tuple"
       }
@@ -625,7 +625,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
@@ -654,7 +654,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "from",
         "type": "tuple"
       },
@@ -663,7 +663,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
modifiedtests/src/eth/abi/nonFungible.jsondiffbeforeafterboth
--- a/tests/src/eth/abi/nonFungible.json
+++ b/tests/src/eth/abi/nonFungible.json
@@ -87,7 +87,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "newAdmin",
         "type": "tuple"
       }
@@ -104,7 +104,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -121,7 +121,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -148,7 +148,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "approved",
         "type": "tuple"
       },
@@ -184,7 +184,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "from",
         "type": "tuple"
       },
@@ -202,7 +202,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "newOwner",
         "type": "tuple"
       }
@@ -221,7 +221,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount[]",
+        "internalType": "struct CrossAddress[]",
         "name": "",
         "type": "tuple[]"
       }
@@ -312,7 +312,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "",
         "type": "tuple"
       }
@@ -355,7 +355,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "",
         "type": "tuple"
       }
@@ -388,7 +388,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "",
         "type": "tuple"
       }
@@ -462,7 +462,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -486,7 +486,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
@@ -582,7 +582,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "admin",
         "type": "tuple"
       }
@@ -606,7 +606,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -737,7 +737,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "sponsor",
         "type": "tuple"
       }
@@ -891,7 +891,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
@@ -920,7 +920,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "from",
         "type": "tuple"
       },
@@ -929,7 +929,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
modifiedtests/src/eth/abi/reFungible.jsondiffbeforeafterboth
--- a/tests/src/eth/abi/reFungible.json
+++ b/tests/src/eth/abi/reFungible.json
@@ -87,7 +87,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "newAdmin",
         "type": "tuple"
       }
@@ -104,7 +104,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -121,7 +121,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -166,7 +166,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "from",
         "type": "tuple"
       },
@@ -184,7 +184,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "newOwner",
         "type": "tuple"
       }
@@ -203,7 +203,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount[]",
+        "internalType": "struct CrossAddress[]",
         "name": "",
         "type": "tuple[]"
       }
@@ -294,7 +294,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "",
         "type": "tuple"
       }
@@ -337,7 +337,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "",
         "type": "tuple"
       }
@@ -370,7 +370,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "",
         "type": "tuple"
       }
@@ -444,7 +444,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -468,7 +468,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
@@ -564,7 +564,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "admin",
         "type": "tuple"
       }
@@ -588,7 +588,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "user",
         "type": "tuple"
       }
@@ -719,7 +719,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "sponsor",
         "type": "tuple"
       }
@@ -882,7 +882,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
@@ -911,7 +911,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "from",
         "type": "tuple"
       },
@@ -920,7 +920,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
modifiedtests/src/eth/abi/reFungibleToken.jsondiffbeforeafterboth
--- a/tests/src/eth/abi/reFungibleToken.json
+++ b/tests/src/eth/abi/reFungibleToken.json
@@ -76,7 +76,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "spender",
         "type": "tuple"
       },
@@ -113,7 +113,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "from",
         "type": "tuple"
       },
@@ -201,7 +201,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
@@ -230,7 +230,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "from",
         "type": "tuple"
       },
@@ -239,7 +239,7 @@
           { "internalType": "address", "name": "eth", "type": "address" },
           { "internalType": "uint256", "name": "sub", "type": "uint256" }
         ],
-        "internalType": "struct CrossAccount",
+        "internalType": "struct CrossAddress",
         "name": "to",
         "type": "tuple"
       },
modifiedtests/src/eth/api/ContractHelpers.soldiffbeforeafterboth
--- a/tests/src/eth/api/ContractHelpers.sol
+++ b/tests/src/eth/api/ContractHelpers.sol
@@ -69,7 +69,7 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x766c4f37,
 	///  or in textual repr: sponsor(address)
-	function sponsor(address contractAddress) external view returns (CrossAccount memory);
+	function sponsor(address contractAddress) external view returns (CrossAddress memory);
 
 	/// Check tat contract has confirmed sponsor.
 	///
@@ -172,7 +172,7 @@
 }
 
 /// @dev Cross account struct
-struct CrossAccount {
+struct CrossAddress {
 	address eth;
 	uint256 sub;
 }
modifiedtests/src/eth/api/UniqueFungible.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueFungible.sol
+++ b/tests/src/eth/api/UniqueFungible.sol
@@ -78,7 +78,7 @@
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
 	/// @dev EVM selector for this function is: 0x84a1d5a8,
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
-	function setCollectionSponsorCross(CrossAccount memory sponsor) external;
+	function setCollectionSponsorCross(CrossAddress memory sponsor) external;
 
 	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
@@ -102,7 +102,7 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
-	function collectionSponsor() external view returns (CrossAccount memory);
+	function collectionSponsor() external view returns (CrossAddress memory);
 
 	/// Get current collection limits.
 	///
@@ -127,13 +127,13 @@
 	/// @param newAdmin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x859aa7d6,
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
-	function addCollectionAdminCross(CrossAccount memory newAdmin) external;
+	function addCollectionAdminCross(CrossAddress memory newAdmin) external;
 
 	/// Remove collection admin.
 	/// @param admin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x6c0cd173,
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
-	function removeCollectionAdminCross(CrossAccount memory admin) external;
+	function removeCollectionAdminCross(CrossAddress memory admin) external;
 
 	// /// Add collection admin.
 	// /// @param newAdmin Address of the added administrator.
@@ -186,7 +186,7 @@
 	/// @param user User address to check.
 	/// @dev EVM selector for this function is: 0x91b6df49,
 	///  or in textual repr: allowlistedCross((address,uint256))
-	function allowlistedCross(CrossAccount memory user) external view returns (bool);
+	function allowlistedCross(CrossAddress memory user) external view returns (bool);
 
 	// /// Add the user to the allowed list.
 	// ///
@@ -200,7 +200,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0xa0184a3a,
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
-	function addToCollectionAllowListCross(CrossAccount memory user) external;
+	function addToCollectionAllowListCross(CrossAddress memory user) external;
 
 	// /// Remove the user from the allowed list.
 	// ///
@@ -214,7 +214,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0x09ba452a,
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
-	function removeFromCollectionAllowListCross(CrossAccount memory user) external;
+	function removeFromCollectionAllowListCross(CrossAddress memory user) external;
 
 	/// Switch permission for minting.
 	///
@@ -237,7 +237,7 @@
 	/// @return "true" if account is the owner or admin
 	/// @dev EVM selector for this function is: 0x3e75a905,
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
-	function isOwnerOrAdminCross(CrossAccount memory user) external view returns (bool);
+	function isOwnerOrAdminCross(CrossAddress memory user) external view returns (bool);
 
 	/// Returns collection type
 	///
@@ -252,7 +252,7 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
-	function collectionOwner() external view returns (CrossAccount memory);
+	function collectionOwner() external view returns (CrossAddress memory);
 
 	// /// Changes collection owner to another account
 	// ///
@@ -268,7 +268,7 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
-	function collectionAdmins() external view returns (CrossAccount[] memory);
+	function collectionAdmins() external view returns (CrossAddress[] memory);
 
 	/// Changes collection owner to another account
 	///
@@ -276,11 +276,11 @@
 	/// @param newOwner new owner cross account
 	/// @dev EVM selector for this function is: 0x6496c497,
 	///  or in textual repr: changeCollectionOwnerCross((address,uint256))
-	function changeCollectionOwnerCross(CrossAccount memory newOwner) external;
+	function changeCollectionOwnerCross(CrossAddress memory newOwner) external;
 }
 
 /// @dev Cross account struct
-struct CrossAccount {
+struct CrossAddress {
 	address eth;
 	uint256 sub;
 }
@@ -354,11 +354,11 @@
 
 	/// @dev EVM selector for this function is: 0x269e6158,
 	///  or in textual repr: mintCross((address,uint256),uint256)
-	function mintCross(CrossAccount memory to, uint256 amount) external returns (bool);
+	function mintCross(CrossAddress memory to, uint256 amount) external returns (bool);
 
 	/// @dev EVM selector for this function is: 0x0ecd0ab0,
 	///  or in textual repr: approveCross((address,uint256),uint256)
-	function approveCross(CrossAccount memory spender, uint256 amount) external returns (bool);
+	function approveCross(CrossAddress memory spender, uint256 amount) external returns (bool);
 
 	// /// Burn tokens from account
 	// /// @dev Function that burns an `amount` of the tokens of a given account,
@@ -376,7 +376,7 @@
 	/// @param amount The amount that will be burnt.
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
-	function burnFromCross(CrossAccount memory from, uint256 amount) external returns (bool);
+	function burnFromCross(CrossAddress memory from, uint256 amount) external returns (bool);
 
 	/// Mint tokens for multiple accounts.
 	/// @param amounts array of pairs of account address and amount
@@ -386,13 +386,13 @@
 
 	/// @dev EVM selector for this function is: 0x2ada85ff,
 	///  or in textual repr: transferCross((address,uint256),uint256)
-	function transferCross(CrossAccount memory to, uint256 amount) external returns (bool);
+	function transferCross(CrossAddress memory to, uint256 amount) external returns (bool);
 
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
-		CrossAccount memory from,
-		CrossAccount memory to,
+		CrossAddress memory from,
+		CrossAddress memory to,
 		uint256 amount
 	) external returns (bool);
 }
modifiedtests/src/eth/api/UniqueNFT.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueNFT.sol
+++ b/tests/src/eth/api/UniqueNFT.sol
@@ -178,7 +178,7 @@
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
 	/// @dev EVM selector for this function is: 0x84a1d5a8,
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
-	function setCollectionSponsorCross(CrossAccount memory sponsor) external;
+	function setCollectionSponsorCross(CrossAddress memory sponsor) external;
 
 	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
@@ -202,7 +202,7 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
-	function collectionSponsor() external view returns (CrossAccount memory);
+	function collectionSponsor() external view returns (CrossAddress memory);
 
 	/// Get current collection limits.
 	///
@@ -227,13 +227,13 @@
 	/// @param newAdmin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x859aa7d6,
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
-	function addCollectionAdminCross(CrossAccount memory newAdmin) external;
+	function addCollectionAdminCross(CrossAddress memory newAdmin) external;
 
 	/// Remove collection admin.
 	/// @param admin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x6c0cd173,
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
-	function removeCollectionAdminCross(CrossAccount memory admin) external;
+	function removeCollectionAdminCross(CrossAddress memory admin) external;
 
 	// /// Add collection admin.
 	// /// @param newAdmin Address of the added administrator.
@@ -286,7 +286,7 @@
 	/// @param user User address to check.
 	/// @dev EVM selector for this function is: 0x91b6df49,
 	///  or in textual repr: allowlistedCross((address,uint256))
-	function allowlistedCross(CrossAccount memory user) external view returns (bool);
+	function allowlistedCross(CrossAddress memory user) external view returns (bool);
 
 	// /// Add the user to the allowed list.
 	// ///
@@ -300,7 +300,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0xa0184a3a,
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
-	function addToCollectionAllowListCross(CrossAccount memory user) external;
+	function addToCollectionAllowListCross(CrossAddress memory user) external;
 
 	// /// Remove the user from the allowed list.
 	// ///
@@ -314,7 +314,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0x09ba452a,
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
-	function removeFromCollectionAllowListCross(CrossAccount memory user) external;
+	function removeFromCollectionAllowListCross(CrossAddress memory user) external;
 
 	/// Switch permission for minting.
 	///
@@ -337,7 +337,7 @@
 	/// @return "true" if account is the owner or admin
 	/// @dev EVM selector for this function is: 0x3e75a905,
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
-	function isOwnerOrAdminCross(CrossAccount memory user) external view returns (bool);
+	function isOwnerOrAdminCross(CrossAddress memory user) external view returns (bool);
 
 	/// Returns collection type
 	///
@@ -352,7 +352,7 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
-	function collectionOwner() external view returns (CrossAccount memory);
+	function collectionOwner() external view returns (CrossAddress memory);
 
 	// /// Changes collection owner to another account
 	// ///
@@ -368,7 +368,7 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
-	function collectionAdmins() external view returns (CrossAccount[] memory);
+	function collectionAdmins() external view returns (CrossAddress[] memory);
 
 	/// Changes collection owner to another account
 	///
@@ -376,11 +376,11 @@
 	/// @param newOwner new owner cross account
 	/// @dev EVM selector for this function is: 0x6496c497,
 	///  or in textual repr: changeCollectionOwnerCross((address,uint256))
-	function changeCollectionOwnerCross(CrossAccount memory newOwner) external;
+	function changeCollectionOwnerCross(CrossAddress memory newOwner) external;
 }
 
 /// @dev Cross account struct
-struct CrossAccount {
+struct CrossAddress {
 	address eth;
 	uint256 sub;
 }
@@ -556,7 +556,7 @@
 	/// @param tokenId Id for the token.
 	/// @dev EVM selector for this function is: 0x2b29dace,
 	///  or in textual repr: crossOwnerOf(uint256)
-	function crossOwnerOf(uint256 tokenId) external view returns (CrossAccount memory);
+	function crossOwnerOf(uint256 tokenId) external view returns (CrossAddress memory);
 
 	/// Returns the token properties.
 	///
@@ -575,7 +575,7 @@
 	/// @param tokenId The NFT to approve
 	/// @dev EVM selector for this function is: 0x0ecd0ab0,
 	///  or in textual repr: approveCross((address,uint256),uint256)
-	function approveCross(CrossAccount memory approved, uint256 tokenId) external;
+	function approveCross(CrossAddress memory approved, uint256 tokenId) external;
 
 	/// @notice Transfer ownership of an NFT
 	/// @dev Throws unless `msg.sender` is the current owner. Throws if `to`
@@ -593,7 +593,7 @@
 	/// @param tokenId The NFT to transfer
 	/// @dev EVM selector for this function is: 0x2ada85ff,
 	///  or in textual repr: transferCross((address,uint256),uint256)
-	function transferCross(CrossAccount memory to, uint256 tokenId) external;
+	function transferCross(CrossAddress memory to, uint256 tokenId) external;
 
 	/// @notice Transfer ownership of an NFT from cross account address to cross account address
 	/// @dev Throws unless `msg.sender` is the current owner. Throws if `to`
@@ -604,8 +604,8 @@
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
-		CrossAccount memory from,
-		CrossAccount memory to,
+		CrossAddress memory from,
+		CrossAddress memory to,
 		uint256 tokenId
 	) external;
 
@@ -627,7 +627,7 @@
 	/// @param tokenId The NFT to transfer
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
-	function burnFromCross(CrossAccount memory from, uint256 tokenId) external;
+	function burnFromCross(CrossAddress memory from, uint256 tokenId) external;
 
 	/// @notice Returns next free NFT ID.
 	/// @dev EVM selector for this function is: 0x75794a3c,
@@ -658,7 +658,7 @@
 	/// @return uint256 The id of the newly minted token
 	/// @dev EVM selector for this function is: 0xb904db03,
 	///  or in textual repr: mintCross((address,uint256),(string,bytes)[])
-	function mintCross(CrossAccount memory to, Property[] memory properties) external returns (uint256);
+	function mintCross(CrossAddress memory to, Property[] memory properties) external returns (uint256);
 }
 
 /// @dev anonymous struct
modifiedtests/src/eth/api/UniqueRefungible.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueRefungible.sol
+++ b/tests/src/eth/api/UniqueRefungible.sol
@@ -178,7 +178,7 @@
 	/// @param sponsor Cross account address of the sponsor from whose account funds will be debited for operations with the contract.
 	/// @dev EVM selector for this function is: 0x84a1d5a8,
 	///  or in textual repr: setCollectionSponsorCross((address,uint256))
-	function setCollectionSponsorCross(CrossAccount memory sponsor) external;
+	function setCollectionSponsorCross(CrossAddress memory sponsor) external;
 
 	/// Whether there is a pending sponsor.
 	/// @dev EVM selector for this function is: 0x058ac185,
@@ -202,7 +202,7 @@
 	/// @return Tuble with sponsor address and his substrate mirror. If there is no confirmed sponsor error "Contract has no sponsor" throw.
 	/// @dev EVM selector for this function is: 0x6ec0a9f1,
 	///  or in textual repr: collectionSponsor()
-	function collectionSponsor() external view returns (CrossAccount memory);
+	function collectionSponsor() external view returns (CrossAddress memory);
 
 	/// Get current collection limits.
 	///
@@ -227,13 +227,13 @@
 	/// @param newAdmin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x859aa7d6,
 	///  or in textual repr: addCollectionAdminCross((address,uint256))
-	function addCollectionAdminCross(CrossAccount memory newAdmin) external;
+	function addCollectionAdminCross(CrossAddress memory newAdmin) external;
 
 	/// Remove collection admin.
 	/// @param admin Cross account administrator address.
 	/// @dev EVM selector for this function is: 0x6c0cd173,
 	///  or in textual repr: removeCollectionAdminCross((address,uint256))
-	function removeCollectionAdminCross(CrossAccount memory admin) external;
+	function removeCollectionAdminCross(CrossAddress memory admin) external;
 
 	// /// Add collection admin.
 	// /// @param newAdmin Address of the added administrator.
@@ -286,7 +286,7 @@
 	/// @param user User address to check.
 	/// @dev EVM selector for this function is: 0x91b6df49,
 	///  or in textual repr: allowlistedCross((address,uint256))
-	function allowlistedCross(CrossAccount memory user) external view returns (bool);
+	function allowlistedCross(CrossAddress memory user) external view returns (bool);
 
 	// /// Add the user to the allowed list.
 	// ///
@@ -300,7 +300,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0xa0184a3a,
 	///  or in textual repr: addToCollectionAllowListCross((address,uint256))
-	function addToCollectionAllowListCross(CrossAccount memory user) external;
+	function addToCollectionAllowListCross(CrossAddress memory user) external;
 
 	// /// Remove the user from the allowed list.
 	// ///
@@ -314,7 +314,7 @@
 	/// @param user User cross account address.
 	/// @dev EVM selector for this function is: 0x09ba452a,
 	///  or in textual repr: removeFromCollectionAllowListCross((address,uint256))
-	function removeFromCollectionAllowListCross(CrossAccount memory user) external;
+	function removeFromCollectionAllowListCross(CrossAddress memory user) external;
 
 	/// Switch permission for minting.
 	///
@@ -337,7 +337,7 @@
 	/// @return "true" if account is the owner or admin
 	/// @dev EVM selector for this function is: 0x3e75a905,
 	///  or in textual repr: isOwnerOrAdminCross((address,uint256))
-	function isOwnerOrAdminCross(CrossAccount memory user) external view returns (bool);
+	function isOwnerOrAdminCross(CrossAddress memory user) external view returns (bool);
 
 	/// Returns collection type
 	///
@@ -352,7 +352,7 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0xdf727d3b,
 	///  or in textual repr: collectionOwner()
-	function collectionOwner() external view returns (CrossAccount memory);
+	function collectionOwner() external view returns (CrossAddress memory);
 
 	// /// Changes collection owner to another account
 	// ///
@@ -368,7 +368,7 @@
 	/// If address is canonical then substrate mirror is zero and vice versa.
 	/// @dev EVM selector for this function is: 0x5813216b,
 	///  or in textual repr: collectionAdmins()
-	function collectionAdmins() external view returns (CrossAccount[] memory);
+	function collectionAdmins() external view returns (CrossAddress[] memory);
 
 	/// Changes collection owner to another account
 	///
@@ -376,11 +376,11 @@
 	/// @param newOwner new owner cross account
 	/// @dev EVM selector for this function is: 0x6496c497,
 	///  or in textual repr: changeCollectionOwnerCross((address,uint256))
-	function changeCollectionOwnerCross(CrossAccount memory newOwner) external;
+	function changeCollectionOwnerCross(CrossAddress memory newOwner) external;
 }
 
 /// @dev Cross account struct
-struct CrossAccount {
+struct CrossAddress {
 	address eth;
 	uint256 sub;
 }
@@ -554,7 +554,7 @@
 	/// @param tokenId Id for the token.
 	/// @dev EVM selector for this function is: 0x2b29dace,
 	///  or in textual repr: crossOwnerOf(uint256)
-	function crossOwnerOf(uint256 tokenId) external view returns (CrossAccount memory);
+	function crossOwnerOf(uint256 tokenId) external view returns (CrossAddress memory);
 
 	/// Returns the token properties.
 	///
@@ -583,7 +583,7 @@
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0x2ada85ff,
 	///  or in textual repr: transferCross((address,uint256),uint256)
-	function transferCross(CrossAccount memory to, uint256 tokenId) external;
+	function transferCross(CrossAddress memory to, uint256 tokenId) external;
 
 	/// @notice Transfer ownership of an RFT
 	/// @dev Throws unless `msg.sender` is the current owner. Throws if `to`
@@ -594,8 +594,8 @@
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
-		CrossAccount memory from,
-		CrossAccount memory to,
+		CrossAddress memory from,
+		CrossAddress memory to,
 		uint256 tokenId
 	) external;
 
@@ -619,7 +619,7 @@
 	/// @param tokenId The RFT to transfer
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
-	function burnFromCross(CrossAccount memory from, uint256 tokenId) external;
+	function burnFromCross(CrossAddress memory from, uint256 tokenId) external;
 
 	/// @notice Returns next free RFT ID.
 	/// @dev EVM selector for this function is: 0x75794a3c,
@@ -650,7 +650,7 @@
 	/// @return uint256 The id of the newly minted token
 	/// @dev EVM selector for this function is: 0xb904db03,
 	///  or in textual repr: mintCross((address,uint256),(string,bytes)[])
-	function mintCross(CrossAccount memory to, Property[] memory properties) external returns (uint256);
+	function mintCross(CrossAddress memory to, Property[] memory properties) external returns (uint256);
 
 	/// Returns EVM address for refungible token
 	///
modifiedtests/src/eth/api/UniqueRefungibleToken.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueRefungibleToken.sol
+++ b/tests/src/eth/api/UniqueRefungibleToken.sol
@@ -39,7 +39,7 @@
 	/// @param amount The amount that will be burnt.
 	/// @dev EVM selector for this function is: 0xbb2f5a58,
 	///  or in textual repr: burnFromCross((address,uint256),uint256)
-	function burnFromCross(CrossAccount memory from, uint256 amount) external returns (bool);
+	function burnFromCross(CrossAddress memory from, uint256 amount) external returns (bool);
 
 	/// @dev Approve the passed address to spend the specified amount of tokens on behalf of `msg.sender`.
 	/// Beware that changing an allowance with this method brings the risk that someone may use both the old
@@ -50,7 +50,7 @@
 	/// @param amount The amount of tokens to be spent.
 	/// @dev EVM selector for this function is: 0x0ecd0ab0,
 	///  or in textual repr: approveCross((address,uint256),uint256)
-	function approveCross(CrossAccount memory spender, uint256 amount) external returns (bool);
+	function approveCross(CrossAddress memory spender, uint256 amount) external returns (bool);
 
 	/// @dev Function that changes total amount of the tokens.
 	///  Throws if `msg.sender` doesn't owns all of the tokens.
@@ -64,7 +64,7 @@
 	/// @param amount The amount to be transferred.
 	/// @dev EVM selector for this function is: 0x2ada85ff,
 	///  or in textual repr: transferCross((address,uint256),uint256)
-	function transferCross(CrossAccount memory to, uint256 amount) external returns (bool);
+	function transferCross(CrossAddress memory to, uint256 amount) external returns (bool);
 
 	/// @dev Transfer tokens from one address to another
 	/// @param from The address which you want to send tokens from
@@ -73,14 +73,14 @@
 	/// @dev EVM selector for this function is: 0xd5cf430b,
 	///  or in textual repr: transferFromCross((address,uint256),(address,uint256),uint256)
 	function transferFromCross(
-		CrossAccount memory from,
-		CrossAccount memory to,
+		CrossAddress memory from,
+		CrossAddress memory to,
 		uint256 amount
 	) external returns (bool);
 }
 
 /// @dev Cross account struct
-struct CrossAccount {
+struct CrossAddress {
 	address eth;
 	uint256 sub;
 }
modifiedtests/src/eth/fractionalizer/Fractionalizer.soldiffbeforeafterboth
--- a/tests/src/eth/fractionalizer/Fractionalizer.sol
+++ b/tests/src/eth/fractionalizer/Fractionalizer.sol
@@ -3,7 +3,7 @@
 import {CollectionHelpers} from "../api/CollectionHelpers.sol";
 import {ContractHelpers} from "../api/ContractHelpers.sol";
 import {UniqueRefungibleToken} from "../api/UniqueRefungibleToken.sol";
-import {UniqueRefungible, CrossAccount} from "../api/UniqueRefungible.sol";
+import {UniqueRefungible, CrossAddress} from "../api/UniqueRefungible.sol";
 import {UniqueNFT} from "../api/UniqueNFT.sol";
 
 /// @dev Fractionalization contract. It stores mappings between NFT and RFT tokens,
@@ -63,7 +63,7 @@
 			"Wrong collection type. Collection is not refungible."
 		);
 		require(
-			refungibleContract.isOwnerOrAdminCross(CrossAccount({eth: address(this), sub: uint256(0)})),
+			refungibleContract.isOwnerOrAdminCross(CrossAddress({eth: address(this), sub: uint256(0)})),
 			"Fractionalizer contract should be an admin of the collection"
 		);
 		rftCollection = _collection;
modifiedtests/src/eth/util/playgrounds/types.tsdiffbeforeafterboth
--- a/tests/src/eth/util/playgrounds/types.ts
+++ b/tests/src/eth/util/playgrounds/types.ts
@@ -19,7 +19,7 @@
   value: bigint,
 }
 
-export interface TEthCrossAccount {
+export interface CrossAddress {
   readonly eth: string,
   readonly sub: string | Uint8Array,
 }
modifiedtests/src/eth/util/playgrounds/unique.dev.tsdiffbeforeafterboth
--- a/tests/src/eth/util/playgrounds/unique.dev.ts
+++ b/tests/src/eth/util/playgrounds/unique.dev.ts
@@ -18,7 +18,7 @@
 
 import {DevUniqueHelper} from '../../../util/playgrounds/unique.dev';
 
-import {ContractImports, CompiledContract, TEthCrossAccount, NormalizedEvent, EthProperty} from './types';
+import {ContractImports, CompiledContract, CrossAddress, NormalizedEvent, EthProperty} from './types';
 
 // Native contracts ABI
 import collectionHelpersAbi from '../../abi/collectionHelpers.json';
@@ -388,7 +388,7 @@
 export type EthUniqueHelperConstructor = new (...args: any[]) => EthUniqueHelper;
 
 export class EthCrossAccountGroup extends EthGroupBase {
-  createAccount(): TEthCrossAccount {
+  createAccount(): CrossAddress {
     return this.fromAddress(this.helper.eth.createAccount());
   }
 
@@ -396,14 +396,14 @@
     return this.fromAddress(await this.helper.eth.createAccountWithBalance(donor, amount));
   }
 
-  fromAddress(address: TEthereumAccount): TEthCrossAccount {
+  fromAddress(address: TEthereumAccount): CrossAddress {
     return {
       eth: address,
       sub: '0',
     };
   }
 
-  fromKeyringPair(keyring: IKeyringPair): TEthCrossAccount {
+  fromKeyringPair(keyring: IKeyringPair): CrossAddress {
     return {
       eth: '0x0000000000000000000000000000000000000000',
       sub: keyring.addressRaw,
--- a/pallets/common/src/eth.rs
+++ b/pallets/common/src/eth.rs
@@ -118,13 +118,13 @@
 
 /// Cross account struct
 #[derive(Debug, Default, AbiCoder)]
-pub struct CrossAccount {
+pub struct CrossAddress {
 	pub(crate) eth: address,
 	pub(crate) sub: uint256,
 }
 
-impl CrossAccount {
-	/// Converts `CrossAccountId` to [`CrossAccount`]
+impl CrossAddress {
+	/// Converts `CrossAccountId` to [`CrossAddress`]
 	pub fn from_sub_cross_account<T>(cross_account_id: &T::CrossAccountId) -> Self
 	where
 		T: pallet_evm::Config,
@@ -139,7 +139,7 @@
 			}
 		}
 	}
 	/// Creates [`CrossAccount`] from substrate account
 	pub fn from_sub<T>(account_id: &T::AccountId) -> Self
 	where
 		T: pallet_evm::Config,
@@ -150,7 +150,7 @@
 			sub: uint256::from_big_endian(account_id.as_ref()),
 		}
 	}
-	/// Converts [`CrossAccount`] to `CrossAccountId`
+	/// Converts [`CrossAddress`] to `CrossAccountId`
 	pub fn into_sub_cross_account<T>(&self) -> evm_coder::execution::Result<T::CrossAccountId>
 	where
 		T: pallet_evm::Config,
@@ -139,7 +139,7 @@
 		}
 	}
-	/// Creates [`CrossAccount`] from substrate account
+	/// Creates [`CrossAddress`] from substrate account
 	pub fn from_sub<T>(account_id: &T::AccountId) -> Self
 	where
modifiedpallets/evm-contract-helpers/src/eth.rsdiffbeforeafterboth